@@ -50,11 +50,9 @@ c               call chAcolAdhoc(pj, ia, iz, a, ntp)
 c            else
 c               call chANewLund(pj, ia, iz, a, ntp)
 c            endif
-#if INCLUSIVE == 1
-      elseif(ActiveMdl .eq. 'inclusive') then
-c                 air target is fixed as N in this case.
-         call cinclusive(pj, a, ntp)
-#endif
+      elseif(ActiveMdl .eq. 'incdpm3') then
+c             dpmjet inclusive treatment
+         call cincdpm3(pj, ia, iz, a, ntp)
       elseif(ActiveMdl .eq. 'byenergy') then
          if( pj.fm.p(4)-pj.mass .gt. 4.0) then
             call chAcolAdhoc(pj, ia, iz, a, ntp)
