@@ -383,7 +383,7 @@ c
 c
         real*8 rf, u
         integer k0
-        character*70  msg
+cc        character*70  msg
 c        
         k0=pj.code
         call rndc(u)
@@ -452,8 +452,9 @@ c              same charge
       elseif(k0 .eq. keta) then
          p.charge = 0
       else
-         write(msg,*) ' code=',k0,' undef. in cfclp'
-         call cerrorMsg(msg, 0)
+c         write(msg,*) ' code=',k0,' undef. in cfclp'
+c         call cerrorMsg(msg, 1)
+c           same charge as input
       endif
       end
       subroutine cslpx(pj,  tmsq, akmin, akmax,  x, notfirst, icon)
