@@ -22,8 +22,8 @@ c
        record /coord/ Offset        ! the primary is directed to 
 c                                     deepest detector origin + Offset
 c                                     (in 'xyz')
-	 
-       real*8 Zfirst       ! to keep first interaction slant depth
+       record /track/ Zfirst ! to keep first interaction info. V7.0
+c       real*8 Zfirst       ! to keep first interaction slant depth
        integer MoveStat    ! status code for moving a particle
        real*8 TargetMassN  ! average target mass number. To be updated
                            ! after a ptcl is moved.
@@ -75,9 +75,9 @@ c                                     (in 'xyz')
 	real*8  MuonPolarization  ! muon polarization value.
 c
        common /Ztrackv/Pwork, IntInfArray, TrackBefMove,
-     *  MovedTrack, Offset,
+     *  MovedTrack, Zfirst, Offset,
      *  Mag, MuonPolarization,  EminAS, EasWait,
-     *  Zfirst,  TargetMassN, TargetAtomicN, TargetZ2,
+     *  TargetMassN, TargetAtomicN, TargetZ2,
      *  EnergyLoss,  KEmin, KEminCas, Beta, 
      *  KEmin2, KEminCas2, Ethin, Upsilon, Xai, 
      *  ObserveAS, Nproduced, 
