@@ -7,10 +7,19 @@ c  ***********************************************************
          subroutine copenf(io, fnin, icon)
 c           io: integer. input.  Fortran logical device number
 c           fnin: character(*). input. Disk file name to be openend.
-c                     if it starts with %_, % is replaced by
-c                     hostname. If %_#_, # is also replaced by
-c                     the cumulative event # .
-c                     The same is true  for the name after /.
+c                     All %, # and @ treated as follows:
+c                  
+c                     @ is replaced by the hostname if PercentEnv is ' '
+c                          If hostname contianes domainname, only hostname
+c                          is extracted.   
+c                     # is replaced by unix process number if SharpEnv is ' '.
+c                     % is replaoced  by YYMMDDHHMMSS if PercentEnv is ' '
+c                  
+c                     In all cases above, if the corresponding variable
+c                     (AtEnv etc is non blank (say, 'XYZ'),
+c                     the envrionmental variable XYZ is assumed to exist
+c                     and its value is used instead of hostname etc.
+c
 c         icon: integer. output. 0--> ok
 c                                1--> cannot be opened.
          implicit none
@@ -35,7 +44,7 @@ c                  see if already opened.
              if(opn) then
                 icon = 0
              elseif(ex) then
-#ifdef PCLinux
+#if defined (PCLinux) || defined (PCLinuxIFC)
 #define SPECIAL 1
 #define DELIM ,delim='apostrophe'
 #else
@@ -112,14 +121,6 @@ c        *******************
  10      continue
 
          call cgetfname(fnin, fn)
-#ifdef   PCLinux
-#define  SPECIAL 1
-#define  DELIM ,delim='apostrophe'
-#else
-#define  SPECIAL 0
-#define  DELIM 
-#endif
-
 c                  see if already opened.
              inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
              if(opn) then
@@ -250,61 +251,100 @@ c          skip to the end of previous write
       subroutine cgetfname(fnin,  fn)
       implicit none
 
-      character*(*) fnin  ! input. If it has %_ at the top or
-                          ! if it has /%_ somewhere, 
-                          ! all % will be replaced by hostname
-                          ! If it is  %_#_ at top or it has /%_#_
-                          ! somewhere, all of # will be replaced by
-                          ! the current cumulative event number.
+      character*(*) fnin  ! input. for  %,  #,  @.
+                          !  see the top of file. 
+
       character*(*) fn    ! output. 
 
 
-      integer j, klena, nl
+      integer j
 
       fn = ' '
       fn = fnin
-      nl = klena(fn)
-      j = 1
-      if( fn(1:2) .eq. '%_') then
-         call creplst( fn, 1 )
-      endif
-      do while( index(fn, '/%_') .gt. 0)
-         j = index(fn, '/%_') + 1
-         call creplst( fn, j)
-      enddo
+
+      j = index (fn, '%') 
+      do while ( j .gt. 0 )
+         call creplst( fn, j,  '%')
+         j = index (fn, '%') 
+      enddo   
+
+      j = index (fn, '#') 
+      do while ( j .gt. 0 )
+         call creplst( fn, j, '#')
+         j = index (fn, '#') 
+      enddo   
+
+      j = index (fn, '@') 
+      do while ( j .gt. 0 )
+         call creplst( fn, j, '@')
+         j = index (fn, '@') 
+      enddo   
+
       end
-      subroutine creplst( fn, j )
+      subroutine creplst( fn, j, ch )
       implicit none
+#include  "Zmanagerp.h"
+
       character*(*) fn   ! input.  must be < 256
-      integer j          ! input.  fn(j:j+1) has  '%_'
+                         ! output
+      integer       j    ! input.  j-th chr pos. has %, # or @ 
 
-      integer num, cumnum, klena, leng, leng2
-      character*10  cnum
-      character*64 host   !  sometimes, the complete name may be obtained
-                          !  so it must be long. 
+      character*1   ch   ! input. one of %, #, @. 
 
-      character*256  fnt
+      integer  klena, leng, kgetpid, dummy, kgetenv2, kgetnow
+ 
+      character*64 replst   ! to contain hostname, etc to replace %, # of or @
 
-      fnt= ' '
-      fnt = fn(j:klena(fn))
-      if( fnt(1:2) .eq. '%_'  .and. 
-     *       fnt(3:4) .eq. '#_' ) then 
-         call cgetHost(leng, host)
-         call cqEventNo(num,  cumnum)
-         cnum = ' '
-         write(cnum, '(i10)') cumnum
-         call kseblk(cnum, '{', leng2)
-         fnt = 
-     *        host(1:leng)//'_'//cnum(1:leng2)//
-     *        '_'//fn(j+4:klena(fn))
-      elseif(fnt(1:2) .eq. '%_') then
-         call cgetHost(leng, host)
-         fnt = host(1:leng)//fn(j+1:klena(fn))
+
+      if( ch  .eq. '@'  ) then
+         if(AtEnv .ne. ' ' ) then
+            leng = kgetenv2(AtEnv, replst)
+            if(leng .eq. 0) then
+               call cerrorMsg(
+     *         'Environmental variable specified by AtEnv=', 1)
+               call cerrorMsg(AtEnv, 1)
+               call cerrorMsg(' Not exist ', 0)
+            endif
+         else   
+            call cgetHost(leng, replst)
+         endif
       endif
-      if(j .gt. 1) then
-         fn = fn(1:j-1)//fnt
+      if(  ch  .eq.  '#' )  then
+         if(SharpEnv .ne. ' ' ) then
+            leng = kgetenv2(SharpEnv, replst)
+            if(leng .eq. 0) then 
+               call cerrorMsg(
+     *         'Environmental variable specified by SharpEnv=', 1)
+               call cerrorMsg(SharpEnv, 1)
+               call cerrorMsg(' Not exist ', 0)
+            endif
+         else
+            replst = ' '
+            write(replst, '(i10)') kgetpid(dummy)
+            call kseblk(replst, '{', leng)
+         endif
+      endif
+
+      if( ch  .eq. '%' ) then
+         if(PercentEnv .ne. ' ' ) then
+            leng = kgetenv2(PercentEnv, replst)
+            if(leng .eq. 0) then 
+               call cerrorMsg(
+     *         'Environmental variable specified by PercentEnv=', 1)
+               call cerrorMsg(PercentEnv, 1)
+               call cerrorMsg(' Not exist ', 0)
+            endif
+         else
+            replst = ' '
+            leng =  kgetnow(replst)  ! get YYMMDDHHMMSS
+            leng =  klena(replst)
+         endif
+      endif
+      if( j .eq. 1 ) then
+         fn = replst(1:leng)//fn(j+1:klena(fn))
       else
-         fn = fnt
+         fn =
+     *   fn(1:j-1)//replst(1:leng)//fn(j+1:klena(fn))
       endif
       end
 c      **************
