@@ -32,7 +32,7 @@ c          den = cthick2den(TrackBefMove.pos.depth)
           call csetIntInf(t*X0, .false., 'compt')
        endif
        if( eg .lt. MaxPhotoE ) then
-          call cphotoEEPath(eg, t)
+          call cphotoEEPath(eg, prob, t)
           call csetIntInf(t*X0, .false., 'photoe')
        endif
        if( eg .gt. MinPhotoProdE .and. PhotoProd ) then
